<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

//if ( !class_exists('WPsite_Flyout_Fire_Core_Functions') ) :

add_action('wp_footer', 	array('WPsite_Flyout_Fire_Core_Functions','display'));

/**
 *
 * Main class for all core functions
 *
 * @since 1.2.5
 */
class WPsite_Flyout_Fire_Core_Functions {

	/**
	 * Hook function to 'wp_footer' to display flyout fire on website
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function display(){

		include_once(WPSITE_FLYOUT_FIRE_PLUGIN_DIR . "/admin/model/db.php");

		global $wpdb;
		global $post;
		global $cat;

		$query = "SELECT * FROM `" . WPsite_Flyout_Fire_DB::getTableName() . "`";
        $data = $wpdb->get_results($query,'ARRAY_A');
        $done = false;

        // Get all post types that are public

		$post_types = get_post_types(array('public' => true));

		// Post Types

		if (!$done && is_singular()) {

			foreach ($data as $val) {

        		$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

	    		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$post_ids = explode(',', $trigger[$post->post_type]['id']);
        		$category_ids = explode(',', $trigger['category']['id']);

	    		// Check if post types match

	    		if (isset($trigger['type']) && $trigger['type'] != $post->post_type && $trigger['type'] != 'category') {
					continue;
		    	}

	    		// ID

        		if (isset($trigger[$post->post_type]['all']) &&
        			!$trigger[$post->post_type]['all'] &&
	    			in_array($post->ID, $post_ids) &&
	    			$val['active'] == 'Active' &&
	    			!$done) {

	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	        }


			foreach ($data as $val) {

        		$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

	    		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$post_ids = explode(',', $trigger[$post->post_type]['id']);
        		$category_ids = explode(',', $trigger['category']['id']);

	    		// Check if post types match

	    		if (isset($trigger['type']) && $trigger['type'] != $post->post_type && $trigger['type'] != 'category' && $trigger['type'] != 'tag') {
					continue;
		    	}

		    	// Tag ID

		    	$tags = explode(',', $trigger['tag']['id']);

        		if ($trigger['type'] == 'tag' &&
        			has_tag($tags,$post->ID) &&
        			$val['active'] == 'Active' &&
        			!$done) {

	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}

        		// Category ID

        		if ($trigger['type'] == 'category' &&
        			isset($trigger['category']['all']) &&
        			!$trigger['category']['all'] &&
	        		$val['active'] == 'Active' &&
        			in_category($category_ids, $post->ID) &&
        			!$done) {

	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}

        		// All

        		if ($trigger['type'] != 'category' &&
        			$trigger['type'] != 'tag' &&
        			isset($trigger[$post->post_type]['all']) &&
        			$trigger[$post->post_type]['all'] &&
        			$val['active'] == 'Active' &&
        			!$done) {

	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	        }
		}

        // Tag

        if (!$done && is_tag()) {
	        foreach ($data as $val) {

        		$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$tags = explode(',', $trigger['tag']['id']);

        		if ($trigger['type'] == 'tag' &&
        			is_tag($tags) &&
        			$val['active'] == 'Active' &&
        			!$done) {

	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	        }
        }

		// Category

        if (!$done && (is_category() || is_single())) {
	        foreach ($data as $val) {

        		$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$category_ids = explode(',', $trigger['category']['id']);

        		if ($trigger['type'] != 'category' || $val['active'] != 'Active' || $done) {
	        		continue;
        		}

        		// ID

        		if (isset($trigger['category']['all']) &&
	        		!$trigger['category']['all'] &&
        			(is_category() && in_array($cat, $category_ids)) ||
        			(is_singular() && in_category($category_ids, $post->ID))) {

	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	       }

	       foreach ($data as $val) {

	        	$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);
        		$category_ids = explode(',', $trigger['category']['id']);

        		if ($trigger['type'] != 'category' || $val['active'] != 'Active' || $done) {
	        		continue;
        		}

        		// All

        		if (isset($trigger['category']['all']) &&
        			$trigger['category']['all'] &&
        			is_category()) {

	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	        }
        }

        // Archive

        if (!$done && is_archive()) {
	        foreach ($data as $val) {

        		$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);

        		if ($trigger['type'] == 'archive' && $val['active'] == 'Active' && !$done) {
	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	        }
        }

        // Front Page

        if (!$done && is_front_page()) {
	        foreach ($data as $val) {

        		$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);

        		if ($trigger['type'] == 'frontpage' && $val['active'] == 'Active' && !$done) {
	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	        }
        }

        // Site

        if (!$done) {
	        foreach ($data as $val) {

        		$args = self::mb_unserialize($val['args']);
        		$trigger = self::mb_unserialize($val['trigger']);

        		// Check that conditions are true

        		if (!self::check_conditions($val['id'], $val['template'], $args, $trigger['args'])) {
	        		continue;
        		}

        		$social = self::mb_unserialize($val['social']);
        		$news_letter = self::mb_unserialize($val['news_letter']);

        		if ($trigger['type'] == 'site' && $val['active'] == 'Active' && !$done) {
	        		self::generate_code($val, $social, $news_letter);
	        		$done = true;
					break;
        		}
	        }
        }
	}

	/**
	 * Checks that all flyout fire conditions are met
	 *
	 * @access public
	 * @static
	 * @param mixed $flyout_fire_id
	 * @param mixed $template
	 * @param mixed $args
	 * @param mixed $trigger
	 * @return void
	 */
	static function check_conditions($flyout_fire_id, $template, $args, $trigger){

		// Check if user has already signed up

		if ($template == 'newsletter' && isset($_COOKIE[WPsite_Flyout_Fire::$prefix . 'email_success_' . $flyout_fire_id])) {
			return false;
		}

		// Check if mobile

    	if (isset($args['mobile']) && $args['mobile'] == 'no' && wp_is_mobile()) {
    		return false;
		}

		// Check user role

		if (!self::check_user_role($trigger)) {
    		return false;
		}

		// Check referrer

		if (!self::check_referrer($trigger)) {
			return false;
		}

		// Date Range

		$now = time();

		if (isset($args['start_date']) && isset($args['end_date']) &&
			(strtotime($args['start_date']) > $now || strtotime($args['end_date']) < $now)) {
    		return false;
		}

		return true;
	}

	/**
	 * Determines if the referrer URL matches any given by the user
	 *
	 * @access public
	 * @static
	 * @param mixed $settings
	 * @return void
	 */
	static function check_referrer($settings) {

		// Return true any domain is checked

		if ($settings['referrer_type'] == 'any') {
			return true;
		}

		// Check is referrer domain matches ones given by user

		else if (isset($_SERVER["HTTP_REFERER"])) {

			$urls = explode(',', $settings['referrer']);
			$domain = parse_url($_SERVER["HTTP_REFERER"]);

			if (in_array($domain['host'], $urls)) {
				return true;
			}
		}

		return false;
	}

	/**
     * Check if the current user has access to backend / frontend based on his role compared with role from settings
     *
     * @access public
     * @static
     * @param mixed $settings
     * @return void
     */
    static function check_user_role($settings) {

		// Check if Everyone users is true

		if (isset($settings['users']) && $settings['users'] == 'everyone') {
			return true;
		}

		// Check if All users is true

		else if (isset($settings['users']) && $settings['users'] == 'logged_in' && is_user_logged_in()) {
			return true;
		}

		// Check if Logged Out Users is true

		else if (isset($settings['users']) && $settings['users'] == 'logged_out' && !is_user_logged_in()) {
			return true;
		}

		// Check if Specific User is true

		else if (isset($settings['users']) && $settings['users'] == 'specific' && is_user_logged_in()) {

			$is_allowed = false;
			global $wp_roles;
			$current_user = wp_get_current_user();

			foreach ($wp_roles->role_names as $role_name => $role) {

				if (isset($settings['user_roles'][$role_name]) && $settings['user_roles'][$role_name] && in_array($role_name, $current_user->roles)) {
					$is_allowed = true;
				}
			}

			return $is_allowed;
		}

        return false;
    }

    /**
	 * Adds the scripts and localizes the variables
	 *
	 * @since 1.0.0
	 *
	 * @param 	$val array of attrs
	 * @return 	N/A
	 */
	static function generate_scripts($val) {

		wp_enqueue_style(WPsite_Flyout_Fire::$prefix . 'fontawesome_css', WPSITE_FLYOUT_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');

		// Google Font Loader

		wp_enqueue_script(WPsite_Flyout_Fire::$prefix . 'google_font_js', WPSITE_FLYOUT_FIRE_PLUGIN_URL .  '/core/js/webfontloader.js');

		$news_letter = self::mb_unserialize($val['news_letter']);
	    $args = self::mb_unserialize($val['args']);
	    $text_link = self::mb_unserialize($val['text_link']);
	    $trigger = self::mb_unserialize($val['trigger']);

	    $slide_direction = isset($args['slide_direction']) ? esc_attr($args['slide_direction']) : $default_flyout_fire['args']['slide_direction'];

	    if ($slide_direction == 'left') {

		    if ($val['location'] == '3' || $val['location'] == '6' || $val['location'] == '9') {
				$slide_direction = 'right';
		    }

	    } else if ($slide_direction == 'up') {

			if ($val['location'] == '7' || $val['location'] == '8' || $val['location'] == '9') {
				$slide_direction = 'down';
		    }
	    }

	    include_once(WPSITE_FLYOUT_FIRE_PLUGIN_DIR . '/admin/functions.php');

	    $default_flyout_fire = WPsite_Flyout_Fire_Admin_Functions::default_flyout_fire();

	    $args_array = array(
	    	'prefix_dash'			=> WPsite_Flyout_Fire::$prefix_dash,
	    	'preview'				=> isset($_GET['action']) && $_GET['action'] == 'preview' ? true : false,
	    	'ajaxurl'				=> admin_url( 'admin-ajax.php' ),
	    	'MailChimp_url'			=> $news_letter['MailChimp']['url'],
	    	'trigger_type'			=> $trigger['args']['type'],
			'timer' 				=> isset($trigger['args']['timer']) ? $trigger['args']['timer'] : $default_flyout_fire['trigger']['args']['timer'],
			'scroll' 				=> isset($trigger['args']['scroll']) ? $trigger['args']['scroll'] : $default_flyout_fire['trigger']['args']['scroll'],
	    	'location' 				=> isset($val['location']) ? esc_attr($val['location']) : $default_flyout_fire['location'],
	    	'link_color' 			=> isset($args['link_color']) ? esc_attr($args['link_color']) : $default_flyout_fire['args']['link_color'],
	    	'icon_color' 			=> isset($args['icon_color']) ? esc_attr($args['icon_color']) : $default_flyout_fire['args']['icon_color'],
	    	'border_color' 			=> isset($args['border_color']) ? esc_attr($args['border_color']) : $default_flyout_fire['args']['border_color'],
	    	'border_size' 			=> isset($args['border_size']) ? esc_attr($args['border_size']) : $default_flyout_fire['args']['border_size'],
	    	'position' 				=> isset($args['position']) ? esc_attr($args['position']) : $default_flyout_fire['args']['position'],
	    	'slide_direction' 		=> $slide_direction,
	    	'effect' 				=> isset($args['effect']) ? esc_attr($args['effect']) : $default_flyout_fire['args']['effect'],
	    	'color' 				=> isset($val['color']) ? esc_attr($val['color']) : $default_flyout_fire['color'],
	    	'text_color' 			=> isset($val['text_color']) ? esc_attr($val['text_color']) : $default_flyout_fire['text_color'],
	    	'display' 				=> isset($val['display']) ? esc_attr($val['display']) : $default_flyout_fire['display'],
	    	'animation' 			=> isset($val['animation']) ? esc_attr($val['animation']) : $default_flyout_fire['animation'],
	    	'link_decoration' 		=> isset($args['link_decoration']) ? $args['link_decoration'] : $default_flyout_fire['args']['link_decoration'],
	    	'font_size' 			=> isset($args['font_size']) ? $args['font_size'] : $default_flyout_fire['args']['font_size'],
	    	'font_weight' 			=> isset($args['font_weight']) ? $args['font_weight'] : $default_flyout_fire['args']['font_weight'],
	    	'heading_font_family' 	=> isset($args['heading_font_family']) ? stripcslashes($args['heading_font_family']) : $default_flyout_fire['args']['heading_font_family'],
	    	'heading_google_fonts' 	=> isset($args['heading_google_fonts']) ? stripcslashes($args['heading_google_fonts']) : $default_flyout_fire['args']['heading_google_fonts'],
	    	'font_family' 			=> isset($args['font_family']) ? stripcslashes($args['font_family']) : $default_flyout_fire['args']['font_family'],
	    	'google_fonts' 			=> isset($args['google_fonts']) ? stripcslashes($args['google_fonts']) : $default_flyout_fire['args']['google_fonts'],
	    	'link_text_color' 		=> isset($text_link['link_text_color']) ? $text_link['link_text_color'] : $default_flyout_fire['text_link']['link_text_color'],
	    	'link_button_color' 	=> isset($text_link['link_button_color']) ? $text_link['link_button_color'] : $default_flyout_fire['text_link']['link_button_color'],
	    	'nl_text_color' 		=> isset($args['nl_text_color']) ? $args['nl_text_color'] : $default_flyout_fire['args']['nl_text_color'],
	    	'nl_button_color' 		=> isset($args['nl_button_color']) ? $args['nl_button_color'] : $default_flyout_fire['args']['nl_button_color'],
	    	'success_action' 		=> isset($news_letter['success_action']) ? $news_letter['success_action'] : $default_flyout_fire['news_letter']['success_action'],
	    	'success_url' 			=> isset($news_letter['success_url']) ? $news_letter['success_url'] : $default_flyout_fire['news_letter']['success_url'],
	    	'social_color' 			=> isset($args['social_color']) ? $args['social_color'] : $default_flyout_fire['args']['social_color'],
	    	'push_pull'				=> isset($args['push_pull']) ? $args['push_pull'] : $default_flyout_fire['args']['push_pull'],
	    	'full'					=> isset($args['full']) ? $args['full'] : $default_flyout_fire['args']['full'],
	    );

	    if (isset($_GET['action']) && $_GET['action'] == 'preview') {

			wp_enqueue_style(WPsite_Flyout_Fire::$prefix . 'preview_css', WPSITE_FLYOUT_FIRE_PLUGIN_URL . '/core/css/flyout-fire.css');
	    	wp_enqueue_script(WPsite_Flyout_Fire::$prefix . 'preview_js', WPSITE_FLYOUT_FIRE_PLUGIN_URL . '/core/js/flyout-fire.js', array(
		    	'jquery',
		    	'jquery-effects-' . $args['effect'],
		    ));

		    wp_localize_script(WPsite_Flyout_Fire::$prefix . 'preview_js', 'wps_ff_data', $args_array);

	    } else {

			wp_enqueue_style(WPsite_Flyout_Fire::$prefix . 'css', WPSITE_FLYOUT_FIRE_PLUGIN_URL . '/core/css/flyout-fire.css');
		    wp_enqueue_script(WPsite_Flyout_Fire::$prefix . 'js', WPSITE_FLYOUT_FIRE_PLUGIN_URL . '/core/js/flyout-fire.js', array(
		    	'jquery',
		    	'jquery-effects-' . $args['effect'],
		    ));

		    wp_localize_script(WPsite_Flyout_Fire::$prefix . 'js', 'wps_ff_data', $args_array);
	    }
	}

	/**
	 * Displays the flyout fire
	 *
	 * @since 1.0.0
	 *
	 * @param 	$val the array of the flyout fire attr
	 * @param 	$social the array of the flyout fire attr
	 * @param 	$news letter the array of the flyout fire attr
	 * @return 	N/A
	 */
	static function generate_code($val, $social, $news_letter) {

		// Include scripts

		self::generate_scripts($val);

		$args = self::mb_unserialize($val['args']);
		$recent_posts = $args['recent_posts'];
		$related_posts = $args['related_posts'];
		$twitter = $args['twitter'];

		$location                 = isset($val['location']) ? $val['location'] : 'top';
		$stub_location            = isset($args['stub_location']) ? $args['stub_location'] : 'right';
		$template                 = isset($val['template']) ? $val['template'] : '';
		$text                     = isset($val['text']) ? $val['text'] : '';
		$link                     = isset($val['link_url']) ? $val['link_url'] : '';
		$link_name                = isset($val['link_name']) ? $val['link_name'] : '';
		$mailchimp_api_key        = isset($news_letter['MailChimp']['api_key']) ? $news_letter['MailChimp']['api_key'] : '';
		$mailchimp_list_id        = isset($news_letter['MailChimp']['list_id']) ? $news_letter['MailChimp']['list_id'] : '';
		$aweber_consumer_key      = isset($news_letter['aweber']['consumer_key']) ? $news_letter['aweber']['consumer_key'] : '';
		$aweber_consumer_secret   = isset($news_letter['aweber']['consumer_secret']) ? $news_letter['aweber']['consumer_secret'] : '';
		$aweber_access_key        = isset($news_letter['aweber']['access_key']) ? $news_letter['aweber']['access_key'] : '';
		$aweber_access_secret     = isset($news_letter['aweber']['access_secret']) ? $news_letter['aweber']['access_secret'] : '';
		$aweber_account_id        = isset($news_letter['aweber']['account_id']) ? $news_letter['aweber']['account_id'] : '';
		$aweber_list_id           = isset($news_letter['aweber']['list_id']) ? $news_letter['aweber']['list_id'] : '';
		$feedburner_id            = isset($news_letter['feedburner']['id']) ? $news_letter['feedburner']['id'] : '';
		$news_letter_type         = isset($news_letter['type']) ? $news_letter['type'] : '';
		$custom                   = isset($val['custom']) ? $val['custom'] : '';

		// Create Background Pattern credit to http://www.patternify.com

		$background = 'style="display:none;';

		// Background Image

		if ($args['background_type'] == 'image') {

			$background_image_attributes = wp_get_attachment_image_src($args["background_image"], 'medium'); // returns an array

			if( $background_image_attributes ) {
				$background .= 'background-image: url(' . $background_image_attributes[0] . ');background-size: cover;"';
			}

		} else if ($args['background_type'] == 'pattern') {

			// Dots

			if ($args['background_pattern'] == 'dots') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAAB1JREFUGBljYGBg4AFiQoAYNYTMGJWHhgAxgckDACfCADFzWBHCAAAAAElFTkSuQmCC);';
			}

			// Diagonal right

			else if ($args['background_pattern'] == 'diagonal_right') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAABVJREFUGBljYCAO8BCjbFQRA/WCAABg/gB584t6RwAAAABJRU5ErkJggg==);';
			}

			// Diagonal left

			else if ($args['background_pattern'] == 'diagonal_left') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAABhJREFUGBljYGBg4AFiosGoYuSgomFoAABg/gB5Q6KWYgAAAABJRU5ErkJggg==);';
			}

			// Grid

			else if ($args['background_pattern'] == 'grid') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAAB1JREFUGBljZGBg4AFiogBRCpmIMgqoaFQh3pACADLgACqd10PPAAAAAElFTkSuQmCC);';
			}

			// Zig Zag

			else if ($args['background_pattern'] == 'zig_zag') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAICAYAAADA+m62AAAAAXNSR0IArs4c6QAAADFJREFUGBljYMAEPJhCmCIwRTAaUwVQBF0SnQ/WhFUQXTMuRTBrCcnD1OG1EUURaRwAYKwAecAGMfQAAAAASUVORK5CYII=);';
			}

			// Diamonds

			else if ($args['background_pattern'] == 'diamonds') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAAEVJREFUGBljYMAEPEAhEMYLkBUgs1E0YZPAEMMQQDICLgdnIEmiM3mY0EUI8fGZiiGHIQA0HZsY2FJkCWQ2VheBFGAoAgCw1ADb2LiCOQAAAABJRU5ErkJggg==);';
			}

			// Hearts

			else if ($args['background_pattern'] == 'hearts') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAADlJREFUGBljYKA14EGzAM5nRJKACyKJwZhfmGAsQjSyiSC12Ez9ApJAV4iuGKwIJIgLYDMZl1oyxQFOKAMqAtJ4RAAAAABJRU5ErkJggg==);';
			}

			// Circles

			else if ($args['background_pattern'] == 'circles') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAADNJREFUGBljYKAH4AFaAsJ4AbICZDaKJmwScDEmFKUkcOAmAPUgs7EaAVJAUBFWnSQJAgBkhAB7H4o0xwAAAABJRU5ErkJggg==);';
			}

			// X Out

			else if ($args['background_pattern'] == 'x_out') {
				$background .= 'background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAAXNSR0IArs4c6QAAADRJREFUGBljYKAl4MFiODYxsDJkCWQ2FjMYGEAKMBQxYVVKhCCySchsFK3YJLCJoWginwMAZIQAe7Ze2SMAAAAASUVORK5CYII=);';
			}
		}

		$background .= '"';

		include_once(WPSITE_FLYOUT_FIRE_PLUGIN_DIR  . '/core/views/flyout-fire.php');
	}

	/**
	 * Mulit-byte Unserialize
	 *
	 * UTF-8 will screw up a serialized string
	 *
	 * @access private
	 * @param string
	 * @return string
	 */
	static function mb_unserialize($string) {
	    $string2 = preg_replace_callback(
	        '!s:(\d+):"(.*?)";!s',
	        function($m){
	            $len = strlen($m[2]);
	            $result = "s:$len:\"{$m[2]}\";";
	            return $result;

	        },
	        $string);
	    return unserialize($string2);
	}

}
//endif;